=== modified file 'src/Contract.vala'
--- src/Contract.vala	2013-05-11 04:00:12 +0000
+++ src/Contract.vala	2013-05-12 08:23:46 +0000
@@ -19,8 +19,8 @@
     public class Contract : Object {
         public string id { get; private set; }
         public string name { get; private set; }
-        public string icon { get; private set; }
-        public string description { get; private set; }
+        public string icon { get; private set; default = ""; }
+        public string description { get; private set; default = ""; }
 
         private MimeTypeManager mimetype_manager;
         private ContractKeyFile keyfile;
@@ -29,14 +29,8 @@
             var contract_file = new ContractFile (file);
             keyfile = new ContractKeyFile (contract_file);
 
-            keyfile.verify_exec ();
-
-            name = keyfile.get_name ();
-            description = keyfile.get_description ();
-            icon = keyfile.get_icon ();
-
-            string[] mimetypes = keyfile.get_mimetypes ();
-            mimetype_manager = new MimeTypeManager (mimetypes);
+            load_mandatory_fields ();
+            load_non_mandatory_fields ();
 
             id = contract_file.get_id ();
         }
@@ -62,5 +56,26 @@
                 icon = icon
             };
         }
+
+        private void load_mandatory_fields () throws Error {
+            name = keyfile.get_name ();
+
+            string[] mimetypes = keyfile.get_mimetypes ();
+            mimetype_manager = new MimeTypeManager (mimetypes);
+        }
+
+        private void load_non_mandatory_fields () {
+            try {
+                description = keyfile.get_description ();
+            } catch (Error err) {
+                warning (err.message);
+            }
+
+            try {
+                icon = keyfile.get_icon ();
+            } catch (Error err) {
+                warning (err.message);
+            }
+        }
     }
 }

=== modified file 'src/ContractKeyFile.vala'
--- src/ContractKeyFile.vala	2013-05-11 04:00:12 +0000
+++ src/ContractKeyFile.vala	2013-05-12 08:23:46 +0000
@@ -42,6 +42,8 @@
         keyfile = new KeyFile ();
         keyfile.load_from_data (contents, contents.length, KeyFileFlags.NONE);
 
+        verify_exec ();
+
         // Add this so that we can use the key file with GDesktopAppInfo.
         keyfile.set_string (KeyFileDesktop.GROUP,
                             KeyFileDesktop.KEY_TYPE,
@@ -62,7 +64,9 @@
     }
 
     public string get_name () throws Error {
-        return get_locale_string (NAME_KEY);
+        string name = get_locale_string (NAME_KEY);
+        verify_string (name, NAME_KEY);
+        return name;
     }
 
     public string get_description () throws Error {
@@ -77,7 +81,7 @@
         return keyfile.get_string_list (DESKTOP_GROUP, MIMETYPE_KEY);
     }
 
-    public void verify_exec () throws Error {
+    private void verify_exec () throws Error {
         string exec = keyfile.get_string (DESKTOP_GROUP, EXEC_KEY);
         verify_string (exec, EXEC_KEY);
     }
@@ -93,11 +97,10 @@
 
     private string get_locale_string (string key) throws Error {
         string locale_string = keyfile.get_locale_string (DESKTOP_GROUP, key);
-        verify_string (locale_string, key);
         return Translations.get_string (text_domain, locale_string);
     }
 
-    private static void verify_string (string str, string key) throws Error {
+    private static void verify_string (string? str, string key) throws Error {
         if (String.is_empty (str))
             throw new KeyFileError.INVALID_VALUE ("%s key is empty.", key);
     }

